<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Katha Pro
 * @since Katha Pro 1.0.0
 * @return array An array of default values
 */

function katha_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$katha_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#ffb72b',
		'header_tagline_color'			=> '#fff',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#000',
		'colorscheme'					=> 'default',
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'spinner-umbrella',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,
		'nav_search_enable'				=> true,
		'menu_style'					=> 'classic-menu',

		// excerpt options
		'long_excerpt_length'           => 25,
		'read_more_text'           		=> esc_html__( 'Continue Reading', 'katha-pro' ),
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s', '1: Year, 2: Site Title with home URL', 'katha-pro' ), '[the-year]', '[site-link]' ),
		'powered_by_text'           	=> esc_html__( 'All Rights Reserved | ', 'katha-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'katha-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'katha-pro' ),
		'hide_date' 					=> false,
		'hide_category'					=> false,
		'hide_comments'					=> false,

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */

		// topbar
		'topbar_social_enable'			=> false,

		// Featured
		'featured_section_enable'		=> true,
		'featured_content_type'			=> 'page',
		'featured_count'				=> 3,

		// about
		'about_section_enable'			=> true,
		'about_content_type'			=> 'custom',
		'about_title'					=> esc_html__( 'Katha is best Theme Now!', 'katha-pro' ),
		'about_content'					=> esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vestibulum fermentum iaculis ex, sit amet sodales augue condimentum eget. Donec ut ornare eros. Maecenas tincidunt risus tellus, ut lacinia justo ultricies id. Curabitur sagittis finibus lacus eleifend congue. Suspendisse ullamcorper ac arcu sed vehicula. Vivamus eget ullamcorper ex. Mauris in est tristique, cursus justo mollis, volutpat lectus et dui sed.', 'katha-pro' ),
		'about_link'					=> '#',
		'about_btn_label'				=> esc_html__( 'Explore Katha', 'katha-pro' ),

		// blog
		'blog_section_enable'			=> true,
		'blog_content_type'				=> 'recent',
		'blog_count'					=> 4,

		// Featured
		'portfolio_section_enable'		=> true,
		'portfolio_content_type'		=> 'recent',
		'portfolio_count'				=> 4,
		'portfolio_title'				=> esc_html__( 'Stories', 'katha-pro' ),
		'portfolio_sub_title'			=> esc_html__( 'Experience the great video story', 'katha-pro' ),



	);

	$output = apply_filters( 'katha_pro_default_theme_options', $katha_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}