<?php
/**
 * About section
 *
 * This is the template for the content of about section
 *
 * @package Theme Palace
 * @subpackage Katha Pro
 * @since Katha Pro 1.0.0
 */
if ( ! function_exists( 'katha_pro_add_about_section' ) ) :
    /**
    * Add about section
    *
    *@since Katha Pro 1.0.0
    */
    function katha_pro_add_about_section() {
    	$options = katha_pro_get_theme_options();
        // Check if about is enabled on frontpage
        $about_enable = apply_filters( 'katha_pro_section_status', true, 'about_section_enable' );

        if ( true !== $about_enable ) {
            return false;
        }
        // Get about section details
        $section_details = array();
        $section_details = apply_filters( 'katha_pro_filter_about_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render about section now.
        katha_pro_render_about_section( $section_details );
    }
endif;
add_action( 'katha_pro_primary_content', 'katha_pro_add_about_section', 20 );

if ( ! function_exists( 'katha_pro_get_about_section_details' ) ) :
    /**
    * about section details.
    *
    * @since Katha Pro 1.0.0
    * @param array $input about section details.
    */
    function katha_pro_get_about_section_details( $input ) {
        $options = katha_pro_get_theme_options();

        // Content type.
        $about_content_type  = $options['about_content_type'];
        
        $content = array();
        switch ( $about_content_type ) {
        	
            case 'custom':
                $custom['title']        = ! empty( $options['about_title'] ) ? $options['about_title'] : '';
                $custom['excerpt']      = ! empty( $options['about_content'] ) ? $options['about_content'] : '';
                $custom['url']          = ! empty( $options['about_link'] ) ? $options['about_link'] : '#.';

                // Push to the main array.
                array_push( $content, $custom );
            break;

            case 'page':
                $page_id = ! empty( $options['about_content_page'] ) ? $options['about_content_page'] : '';

                if ( empty( $page_id ) )
                    return $input;
                
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                     
            break;

            case 'post':
                $post_id = ! empty( $options['about_content_post'] ) ? $options['about_content_post'] : '';

                if ( empty( $post_id ) )
                    return $input;
                
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );            
            break;

            default:
            break;
        }

        if ( 'custom' !== $about_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']  	= katha_pro_trim_content( 50 );
                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        endif;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// about section content details.
add_filter( 'katha_pro_filter_about_section_details', 'katha_pro_get_about_section_details' );


if ( ! function_exists( 'katha_pro_render_about_section' ) ) :
  /**
   * Start about section
   *
   * @return string about content
   * @since Katha Pro 1.0.0
   *
   */
   function katha_pro_render_about_section( $content_details = array() ) {
        $options = katha_pro_get_theme_options();
        $about_btn_label  = ! empty( $options['about_btn_label'] ) ? $options['about_btn_label'] : esc_html__( 'Explore Katha', 'katha-pro' );

        if ( empty( $content_details ) ) {
            return;
        } 

        foreach ( $content_details as $content ) :
        ?>
        <div id="about-us" class="page-section col-2 clear">
                <div class="wrapper">
                    <div class="entry-container">
                        <?php if ( ! empty( $content['title'] ) ) : ?>
                            <div class="hentry">
                               <header class="entry-header">
                                   <h2 class="entry-title"><?php echo esc_html( $content['title'] ); ?></h2>
                                   <div class="seperator"></div>
                               </header>
                            </div><!-- .hentry -->
                        <?php endif; ?>

                        <div class="hentry">
                            <div class="entry-content">
                                <?php if ( ! empty( $content['excerpt'] ) ) : ?>
                                    <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                <?php endif; ?>

                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn btn-white"><?php echo esc_html( $about_btn_label ) . katha_pro_get_svg( array( 'icon' => 'right' ) ); ?></a>
                            </div><!-- .entry-content -->
                        </div><!-- .hentry -->
                    </div><!-- .entry-container -->
                </div><!-- .wrapper -->
            </div><!-- #about-us -->
        <?php 
        endforeach;
    }
endif;