<?php
/**
 * Blog section
 *
 * This is the template for the content of blog section
 *
 * @package Theme Palace
 * @subpackage Katha Pro
 * @since Katha Pro 1.0.0
 */
if ( ! function_exists( 'katha_pro_add_blog_section' ) ) :
    /**
    * Add blog section
    *
    *@since Katha Pro 1.0.0
    */
    function katha_pro_add_blog_section() {
    	$options = katha_pro_get_theme_options();
        // Check if blog is enabled on frontpage
        $blog_enable = apply_filters( 'katha_pro_section_status', true, 'blog_section_enable' );

        if ( true !== $blog_enable ) {
            return false;
        }
        // Get blog section details
        $section_details = array();
        $section_details = apply_filters( 'katha_pro_filter_blog_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render blog section now.
        katha_pro_render_blog_section( $section_details );
    }
endif;
add_action( 'katha_pro_primary_content', 'katha_pro_add_blog_section', 30 );

if ( ! function_exists( 'katha_pro_get_blog_section_details' ) ) :
    /**
    * blog section details.
    *
    * @since Katha Pro 1.0.0
    * @param array $input blog section details.
    */
    function katha_pro_get_blog_section_details( $input ) {
        $options = katha_pro_get_theme_options();

        // Content type.
        $blog_content_type  = $options['blog_content_type'];
        $blog_count = ! empty( $options['blog_count'] ) ? $options['blog_count'] : 4;
        
        $content = array();
        switch ( $blog_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $blog_count; $i++ ) {
                    if ( ! empty( $options['blog_content_page_' . $i] ) )
                        $page_ids[] = $options['blog_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $blog_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $blog_count; $i++ ) {
                    if ( ! empty( $options['blog_content_post_' . $i] ) )
                        $post_ids[] = $options['blog_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $blog_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['blog_content_category'] ) ? $options['blog_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $blog_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'recent':
                $cat_ids = ! empty( $options['blog_category_exclude'] ) ? $options['blog_category_exclude'] : array();
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $blog_count ),
                    'category__not_in'  => ( array ) $cat_ids,
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = katha_pro_trim_content( 35 );
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// blog section content details.
add_filter( 'katha_pro_filter_blog_section_details', 'katha_pro_get_blog_section_details' );


if ( ! function_exists( 'katha_pro_render_blog_section' ) ) :
  /**
   * Start blog section
   *
   * @return string blog content
   * @since Katha Pro 1.0.0
   *
   */
   function katha_pro_render_blog_section( $content_details = array() ) {
        $options = katha_pro_get_theme_options();
        $blog_content_type  = $options['blog_content_type'];
        $readmore = ! empty( $options['read_more_text'] ) ? $options['read_more_text'] : esc_html__( 'Continue Reading', 'katha-pro' );

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="latest-post" class="page-section no-padding-bottom clear">
                <div class="wrapper">
                    <div class="blog-posts-wrapper">
                        <?php foreach ( $content_details as $content ) : ?>
                            <article class="hentry <?php echo ! empty( $content['image'] ) ? 'has-post-thumbnail' : 'no-post-thumbnail'; ?>">
                                <?php if ( ! empty( $content['image'] ) ) : ?>
                                    <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                    </div><!-- .featured-image -->
                                <?php endif; ?>

                                <div class="entry-container">
                                    <header class="entry-header">
                                        <?php if ( 'page' != $blog_content_type ) : ?>
                                            <span class="sub-title">
                                                <?php the_category( '', '', $content['id'] ); ?>
                                            </span>
                                        <?php endif; ?>
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>
                                    <div class="entry-content">
                                       <?php echo esc_html( $content['excerpt'] ); ?>
                                    </div><!-- .entry-content -->

                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn btn-black"><?php echo esc_html( $readmore ) . katha_pro_get_svg( array( 'icon' => 'right' ) ); ?></a>
                                </div><!-- .entry-container -->
                            </article><!-- .slick-item -->
                        <?php endforeach; ?>
                    </div><!-- .blog-posts-wrapper -->
                </div><!-- .wrapper -->
            </div><!-- #latest-projects -->

    <?php }
endif;