<?php
/**
 * Featured section
 *
 * This is the template for the content of featured section
 *
 * @package Theme Palace
 * @subpackage Katha Pro
 * @since Katha Pro 1.0.0
 */
if ( ! function_exists( 'katha_pro_add_featured_section' ) ) :
    /**
    * Add featured section
    *
    *@since Katha Pro 1.0.0
    */
    function katha_pro_add_featured_section() {
    	$options = katha_pro_get_theme_options();
        // Check if featured is enabled on frontpage
        $featured_enable = apply_filters( 'katha_pro_section_status', true, 'featured_section_enable' );

        if ( true !== $featured_enable ) {
            return false;
        }
        // Get featured section details
        $section_details = array();
        $section_details = apply_filters( 'katha_pro_filter_featured_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render featured section now.
        katha_pro_render_featured_section( $section_details );
    }
endif;
add_action( 'katha_pro_primary_content', 'katha_pro_add_featured_section', 10 );

if ( ! function_exists( 'katha_pro_get_featured_section_details' ) ) :
    /**
    * featured section details.
    *
    * @since Katha Pro 1.0.0
    * @param array $input featured section details.
    */
    function katha_pro_get_featured_section_details( $input ) {
        $options = katha_pro_get_theme_options();

        // Content type.
        $featured_content_type  = $options['featured_content_type'];
        $featured_count = ! empty( $options['featured_count'] ) ? $options['featured_count'] : 3;
        
        $content = array();
        switch ( $featured_content_type ) {
        	
            case 'custom':
                for ( $i = 1; $i <= $featured_count; $i++ ) {
                    $custom['title']        = ! empty( $options['featured_title_' . $i] ) ? $options['featured_title_' . $i] : '';
                    $custom['image']        = ! empty( $options['featured_image_' . $i] ) ? $options['featured_image_' . $i] : get_template_directory_uri() . '/assets/uploads/no-featured-image-587x775.jpg';
                    $custom['url']          = ! empty( $options['featured_link_' . $i] ) ? $options['featured_link_' . $i] : '#';

                    // Push to the main array.
                    array_push( $content, $custom );
                }
            break;

            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $featured_count; $i++ ) {
                    if ( ! empty( $options['featured_content_page_' . $i] ) )
                        $page_ids[] = $options['featured_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $featured_count ),
                    'orderby'           => 'post__in',
                    );                     
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $featured_count; $i++ ) {
                    if ( ! empty( $options['featured_content_post_' . $i] ) )
                        $post_ids[] = $options['featured_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $featured_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );   
            break;

            case 'category':
                $cat_id = ! empty( $options['featured_content_category'] ) ? $options['featured_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $featured_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        if ( 'custom' !== $featured_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'medium_large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-587x775.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        endif;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// featured section content details.
add_filter( 'katha_pro_filter_featured_section_details', 'katha_pro_get_featured_section_details' );


if ( ! function_exists( 'katha_pro_render_featured_section' ) ) :
  /**
   * Start featured section
   *
   * @return string featured content
   * @since Katha Pro 1.0.0
   *
   */
   function katha_pro_render_featured_section( $content_details = array() ) {
        $options = katha_pro_get_theme_options();
        $featured_content_type  = $options['featured_content_type'];
        $featured_count = ! empty( $options['featured_count'] ) ? $options['featured_count'] : 3;

        if ( empty( $content_details ) ) {
            return;
        } 
        ?>
        <div id="featured-post">
               <div class="wrapper col-<?php echo absint( $featured_count ); ?> clear">
                    <?php foreach ( $content_details as $content ) : ?>
                        <article class="hentry">
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                <div class="entry-container">
                                    <?php if ( in_array( $featured_content_type, array( 'post', 'category' ) ) ) : ?>
                                        <div class="entry-meta">
                                           <span class="cat-links">
                                                <?php the_category( '', '', $content['id'] ); ?>
                                            </span><!-- .post-categories -->
                                        </div><!-- .entry-meta -->
                                    <?php endif;

                                    if ( ! empty( $content['title'] ) ) : ?>
                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                        </header><!-- .entry-header -->
                                    <?php endif; ?>
                                </div><!-- .entry-container -->
                            </div><!-- .featured-image -->
                            <div class="entry-container">
                                <?php if ( in_array( $featured_content_type, array( 'post', 'category' ) ) ) : ?>
                                    <div class="entry-meta">
                                       <span class="cat-links">
                                            <?php the_category( '', '', $content['id'] ); ?>
                                        </span><!-- .post-categories -->
                                    </div><!-- .entry-meta -->
                                <?php endif;

                                if ( ! empty( $content['title'] ) ) : ?>
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header><!-- .entry-header -->
                                <?php endif; ?>
                           </div><!-- .entry-container -->
                        </article><!-- .article -->
                    <?php endforeach; ?>
               </div><!-- .wrapper -->
           </div><!-- #featured-post -->
        <?php 
    }
endif;